@@ -208,6 +208,7 @@ anjuta_vcs_status_get_type (void)
       { ANJUTA_VCS_STATUS_MISSING, "ANJUTA_VCS_STATUS_MISSING", "missing" },
       { ANJUTA_VCS_STATUS_UNVERSIONED, "ANJUTA_VCS_STATUS_UNVERSIONED", "unversioned" },
       { ANJUTA_VCS_STATUS_IGNORED, "ANJUTA_VCS_STATUS_IGNORED", "ignored" },
+      { ANJUTA_VCS_STATUS_ALL, "ANJUTA_VCS_STATUS_ALL", "all" },
       { 0, NULL, NULL }
     };
     etype = g_flags_register_static (g_intern_static_string ("AnjutaVcsStatus"), values);
@@ -215,88 +216,198 @@ anjuta_vcs_status_get_type (void)
   return etype;
 }
 
-/* enumerations from "gbf-project.h" */
+/* enumerations from "anjuta-project.h" */
 GType
-gbf_project_error_get_type (void)
+anjuta_project_value_type_get_type (void)
 {
   static GType etype = 0;
   if (etype == 0) {
     static const GEnumValue values[] = {
-      { GBF_PROJECT_ERROR_SUCCESS, "GBF_PROJECT_ERROR_SUCCESS", "success" },
-      { GBF_PROJECT_ERROR_DOESNT_EXIST, "GBF_PROJECT_ERROR_DOESNT_EXIST", "doesnt-exist" },
-      { GBF_PROJECT_ERROR_ALREADY_EXISTS, "GBF_PROJECT_ERROR_ALREADY_EXISTS", "already-exists" },
-      { GBF_PROJECT_ERROR_VALIDATION_FAILED, "GBF_PROJECT_ERROR_VALIDATION_FAILED", "validation-failed" },
-      { GBF_PROJECT_ERROR_PROJECT_MALFORMED, "GBF_PROJECT_ERROR_PROJECT_MALFORMED", "project-malformed" },
-      { GBF_PROJECT_ERROR_GENERAL_FAILURE, "GBF_PROJECT_ERROR_GENERAL_FAILURE", "general-failure" },
+      { ANJUTA_PROJECT_PROPERTY_STRING, "ANJUTA_PROJECT_PROPERTY_STRING", "string" },
+      { ANJUTA_PROJECT_PROPERTY_LIST, "ANJUTA_PROJECT_PROPERTY_LIST", "list" },
+      { ANJUTA_PROJECT_PROPERTY_BOOLEAN, "ANJUTA_PROJECT_PROPERTY_BOOLEAN", "boolean" },
+      { ANJUTA_PROJECT_PROPERTY_MAP, "ANJUTA_PROJECT_PROPERTY_MAP", "map" },
       { 0, NULL, NULL }
     };
-    etype = g_enum_register_static (g_intern_static_string ("GbfProjectError"), values);
+    etype = g_enum_register_static (g_intern_static_string ("AnjutaProjectValueType"), values);
   }
   return etype;
 }
 GType
-gbf_project_capabilities_get_type (void)
+anjuta_project_property_flags_get_type (void)
 {
   static GType etype = 0;
   if (etype == 0) {
     static const GFlagsValue values[] = {
-      { GBF_PROJECT_CAN_ADD_NONE, "GBF_PROJECT_CAN_ADD_NONE", "add-none" },
-      { GBF_PROJECT_CAN_ADD_GROUP, "GBF_PROJECT_CAN_ADD_GROUP", "add-group" },
-      { GBF_PROJECT_CAN_ADD_TARGET, "GBF_PROJECT_CAN_ADD_TARGET", "add-target" },
-      { GBF_PROJECT_CAN_ADD_SOURCE, "GBF_PROJECT_CAN_ADD_SOURCE", "add-source" },
-      { GBF_PROJECT_CAN_PACKAGES, "GBF_PROJECT_CAN_PACKAGES", "packages" },
+      { ANJUTA_PROJECT_PROPERTY_READ_ONLY, "ANJUTA_PROJECT_PROPERTY_READ_ONLY", "only" },
+      { ANJUTA_PROJECT_PROPERTY_READ_WRITE, "ANJUTA_PROJECT_PROPERTY_READ_WRITE", "write" },
       { 0, NULL, NULL }
     };
-    etype = g_flags_register_static (g_intern_static_string ("GbfProjectCapabilities"), values);
+    etype = g_flags_register_static (g_intern_static_string ("AnjutaProjectPropertyFlags"), values);
   }
   return etype;
 }
-
-/* enumerations from "anjuta-project.h" */
 GType
 anjuta_project_node_type_get_type (void)
 {
   static GType etype = 0;
   if (etype == 0) {
-    static const GEnumValue values[] = {
+    static const GFlagsValue values[] = {
       { ANJUTA_PROJECT_UNKNOWN, "ANJUTA_PROJECT_UNKNOWN", "unknown" },
+      { ANJUTA_PROJECT_SHAREDLIB, "ANJUTA_PROJECT_SHAREDLIB", "sharedlib" },
+      { ANJUTA_PROJECT_STATICLIB, "ANJUTA_PROJECT_STATICLIB", "staticlib" },
+      { ANJUTA_PROJECT_PROGRAM, "ANJUTA_PROJECT_PROGRAM", "program" },
+      { ANJUTA_PROJECT_PYTHON, "ANJUTA_PROJECT_PYTHON", "python" },
+      { ANJUTA_PROJECT_JAVA, "ANJUTA_PROJECT_JAVA", "java" },
+      { ANJUTA_PROJECT_LISP, "ANJUTA_PROJECT_LISP", "lisp" },
+      { ANJUTA_PROJECT_HEADER, "ANJUTA_PROJECT_HEADER", "header" },
+      { ANJUTA_PROJECT_MAN, "ANJUTA_PROJECT_MAN", "man" },
+      { ANJUTA_PROJECT_INFO, "ANJUTA_PROJECT_INFO", "info" },
+      { ANJUTA_PROJECT_GENERIC, "ANJUTA_PROJECT_GENERIC", "generic" },
+      { ANJUTA_PROJECT_DATA, "ANJUTA_PROJECT_DATA", "data" },
+      { ANJUTA_PROJECT_EXTRA, "ANJUTA_PROJECT_EXTRA", "extra" },
+      { ANJUTA_PROJECT_INTLTOOL, "ANJUTA_PROJECT_INTLTOOL", "intltool" },
+      { ANJUTA_PROJECT_CONFIGURE, "ANJUTA_PROJECT_CONFIGURE", "configure" },
+      { ANJUTA_PROJECT_IDL, "ANJUTA_PROJECT_IDL", "idl" },
+      { ANJUTA_PROJECT_MKENUMS, "ANJUTA_PROJECT_MKENUMS", "mkenums" },
+      { ANJUTA_PROJECT_GENMARSHAL, "ANJUTA_PROJECT_GENMARSHAL", "genmarshal" },
+      { ANJUTA_PROJECT_SCRIPT, "ANJUTA_PROJECT_SCRIPT", "script" },
+      { ANJUTA_PROJECT_PROXY, "ANJUTA_PROJECT_PROXY", "proxy" },
+      { ANJUTA_PROJECT_PROJECT, "ANJUTA_PROJECT_PROJECT", "project" },
+      { ANJUTA_PROJECT_PRIMARY, "ANJUTA_PROJECT_PRIMARY", "primary" },
+      { ANJUTA_PROJECT_EXECUTABLE, "ANJUTA_PROJECT_EXECUTABLE", "executable" },
+      { ANJUTA_PROJECT_READ_ONLY, "ANJUTA_PROJECT_READ_ONLY", "read-only" },
+      { ANJUTA_PROJECT_ID_MASK, "ANJUTA_PROJECT_ID_MASK", "id-mask" },
+      { ANJUTA_PROJECT_FLAG_MASK, "ANJUTA_PROJECT_FLAG_MASK", "flag-mask" },
+      { ANJUTA_PROJECT_TYPE_MASK, "ANJUTA_PROJECT_TYPE_MASK", "type-mask" },
+      { ANJUTA_PROJECT_ROOT, "ANJUTA_PROJECT_ROOT", "root" },
       { ANJUTA_PROJECT_GROUP, "ANJUTA_PROJECT_GROUP", "group" },
       { ANJUTA_PROJECT_TARGET, "ANJUTA_PROJECT_TARGET", "target" },
       { ANJUTA_PROJECT_SOURCE, "ANJUTA_PROJECT_SOURCE", "source" },
+      { ANJUTA_PROJECT_MODULE, "ANJUTA_PROJECT_MODULE", "module" },
+      { ANJUTA_PROJECT_PACKAGE, "ANJUTA_PROJECT_PACKAGE", "package" },
       { ANJUTA_PROJECT_VARIABLE, "ANJUTA_PROJECT_VARIABLE", "variable" },
       { 0, NULL, NULL }
     };
-    etype = g_enum_register_static (g_intern_static_string ("AnjutaProjectNodeType"), values);
+    etype = g_flags_register_static (g_intern_static_string ("AnjutaProjectNodeType"), values);
   }
   return etype;
 }
 GType
-anjuta_project_target_class_get_type (void)
+anjuta_project_node_state_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GFlagsValue values[] = {
+      { ANJUTA_PROJECT_OK, "ANJUTA_PROJECT_OK", "ok" },
+      { ANJUTA_PROJECT_MODIFIED, "ANJUTA_PROJECT_MODIFIED", "modified" },
+      { ANJUTA_PROJECT_INCOMPLETE, "ANJUTA_PROJECT_INCOMPLETE", "incomplete" },
+      { ANJUTA_PROJECT_LOADING, "ANJUTA_PROJECT_LOADING", "loading" },
+      { ANJUTA_PROJECT_REMOVED, "ANJUTA_PROJECT_REMOVED", "removed" },
+      { ANJUTA_PROJECT_CAN_ADD_GROUP, "ANJUTA_PROJECT_CAN_ADD_GROUP", "can-add-group" },
+      { ANJUTA_PROJECT_CAN_ADD_TARGET, "ANJUTA_PROJECT_CAN_ADD_TARGET", "can-add-target" },
+      { ANJUTA_PROJECT_CAN_ADD_SOURCE, "ANJUTA_PROJECT_CAN_ADD_SOURCE", "can-add-source" },
+      { ANJUTA_PROJECT_CAN_ADD_MODULE, "ANJUTA_PROJECT_CAN_ADD_MODULE", "can-add-module" },
+      { ANJUTA_PROJECT_CAN_ADD_PACKAGE, "ANJUTA_PROJECT_CAN_ADD_PACKAGE", "can-add-package" },
+      { ANJUTA_PROJECT_CAN_REMOVE, "ANJUTA_PROJECT_CAN_REMOVE", "can-remove" },
+      { ANJUTA_PROJECT_CAN_SAVE, "ANJUTA_PROJECT_CAN_SAVE", "can-save" },
+      { ANJUTA_PROJECT_REMOVE_FILE, "ANJUTA_PROJECT_REMOVE_FILE", "remove-file" },
+      { 0, NULL, NULL }
+    };
+    etype = g_flags_register_static (g_intern_static_string ("AnjutaProjectNodeState"), values);
+  }
+  return etype;
+}
+
+/* enumerations from "anjuta-command-queue.h" */
+GType
+anjuta_command_queue_execute_mode_get_type (void)
 {
   static GType etype = 0;
   if (etype == 0) {
     static const GEnumValue values[] = {
-      { ANJUTA_TARGET_UNKNOWN, "ANJUTA_TARGET_UNKNOWN", "unknown" },
-      { ANJUTA_TARGET_SHAREDLIB, "ANJUTA_TARGET_SHAREDLIB", "sharedlib" },
-      { ANJUTA_TARGET_STATICLIB, "ANJUTA_TARGET_STATICLIB", "staticlib" },
-      { ANJUTA_TARGET_EXECUTABLE, "ANJUTA_TARGET_EXECUTABLE", "executable" },
-      { ANJUTA_TARGET_PYTHON, "ANJUTA_TARGET_PYTHON", "python" },
-      { ANJUTA_TARGET_JAVA, "ANJUTA_TARGET_JAVA", "java" },
-      { ANJUTA_TARGET_LISP, "ANJUTA_TARGET_LISP", "lisp" },
-      { ANJUTA_TARGET_HEADER, "ANJUTA_TARGET_HEADER", "header" },
-      { ANJUTA_TARGET_MAN, "ANJUTA_TARGET_MAN", "man" },
-      { ANJUTA_TARGET_INFO, "ANJUTA_TARGET_INFO", "info" },
-      { ANJUTA_TARGET_GENERIC, "ANJUTA_TARGET_GENERIC", "generic" },
-      { ANJUTA_TARGET_DATA, "ANJUTA_TARGET_DATA", "data" },
-      { ANJUTA_TARGET_EXTRA, "ANJUTA_TARGET_EXTRA", "extra" },
-      { ANJUTA_TARGET_INTLTOOL, "ANJUTA_TARGET_INTLTOOL", "intltool" },
-      { ANJUTA_TARGET_CONFIGURE, "ANJUTA_TARGET_CONFIGURE", "configure" },
-      { ANJUTA_TARGET_IDL, "ANJUTA_TARGET_IDL", "idl" },
-      { ANJUTA_TARGET_MKENUMS, "ANJUTA_TARGET_MKENUMS", "mkenums" },
-      { ANJUTA_TARGET_GENMARSHAL, "ANJUTA_TARGET_GENMARSHAL", "genmarshal" },
+      { ANJUTA_COMMAND_QUEUE_EXECUTE_AUTOMATIC, "ANJUTA_COMMAND_QUEUE_EXECUTE_AUTOMATIC", "automatic" },
+      { ANJUTA_COMMAND_QUEUE_EXECUTE_MANUAL, "ANJUTA_COMMAND_QUEUE_EXECUTE_MANUAL", "manual" },
       { 0, NULL, NULL }
     };
-    etype = g_enum_register_static (g_intern_static_string ("AnjutaProjectTargetClass"), values);
+    etype = g_enum_register_static (g_intern_static_string ("AnjutaCommandQueueExecuteMode"), values);
+  }
+  return etype;
+}
+
+/* enumerations from "anjuta-command-bar.h" */
+GType
+anjuta_command_bar_entry_type_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GEnumValue values[] = {
+      { ANJUTA_COMMAND_BAR_ENTRY_FRAME, "ANJUTA_COMMAND_BAR_ENTRY_FRAME", "frame" },
+      { ANJUTA_COMMAND_BAR_ENTRY_BUTTON, "ANJUTA_COMMAND_BAR_ENTRY_BUTTON", "button" },
+      { 0, NULL, NULL }
+    };
+    etype = g_enum_register_static (g_intern_static_string ("AnjutaCommandBarEntryType"), values);
+  }
+  return etype;
+}
+
+/* enumerations from "anjuta-token.h" */
+GType
+anjuta_token_type_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GFlagsValue values[] = {
+      { ANJUTA_TOKEN_NONE, "ANJUTA_TOKEN_NONE", "none" },
+      { ANJUTA_TOKEN_EOL, "ANJUTA_TOKEN_EOL", "eol" },
+      { ANJUTA_TOKEN_COMMA, "ANJUTA_TOKEN_COMMA", "comma" },
+      { ANJUTA_TOKEN_TYPE, "ANJUTA_TOKEN_TYPE", "type" },
+      { ANJUTA_TOKEN_FIRST, "ANJUTA_TOKEN_FIRST", "first" },
+      { ANJUTA_TOKEN_FILE, "ANJUTA_TOKEN_FILE", "file" },
+      { ANJUTA_TOKEN_MACRO, "ANJUTA_TOKEN_MACRO", "macro" },
+      { ANJUTA_TOKEN_CONTENT, "ANJUTA_TOKEN_CONTENT", "content" },
+      { ANJUTA_TOKEN_ARGUMENT, "ANJUTA_TOKEN_ARGUMENT", "argument" },
+      { ANJUTA_TOKEN_VALUE, "ANJUTA_TOKEN_VALUE", "value" },
+      { ANJUTA_TOKEN_EOV, "ANJUTA_TOKEN_EOV", "eov" },
+      { ANJUTA_TOKEN_PARSED, "ANJUTA_TOKEN_PARSED", "parsed" },
+      { ANJUTA_TOKEN_KEYWORD, "ANJUTA_TOKEN_KEYWORD", "keyword" },
+      { ANJUTA_TOKEN_OPERATOR, "ANJUTA_TOKEN_OPERATOR", "operator" },
+      { ANJUTA_TOKEN_NAME, "ANJUTA_TOKEN_NAME", "name" },
+      { ANJUTA_TOKEN_VARIABLE, "ANJUTA_TOKEN_VARIABLE", "variable" },
+      { ANJUTA_TOKEN_DEFINITION, "ANJUTA_TOKEN_DEFINITION", "definition" },
+      { ANJUTA_TOKEN_STATEMENT, "ANJUTA_TOKEN_STATEMENT", "statement" },
+      { ANJUTA_TOKEN_NUMBER, "ANJUTA_TOKEN_NUMBER", "number" },
+      { ANJUTA_TOKEN_JUNK, "ANJUTA_TOKEN_JUNK", "junk" },
+      { ANJUTA_TOKEN_COMMENT, "ANJUTA_TOKEN_COMMENT", "comment" },
+      { ANJUTA_TOKEN_OPEN_QUOTE, "ANJUTA_TOKEN_OPEN_QUOTE", "open-quote" },
+      { ANJUTA_TOKEN_CLOSE_QUOTE, "ANJUTA_TOKEN_CLOSE_QUOTE", "close-quote" },
+      { ANJUTA_TOKEN_ESCAPE, "ANJUTA_TOKEN_ESCAPE", "escape" },
+      { ANJUTA_TOKEN_FUNCTION, "ANJUTA_TOKEN_FUNCTION", "function" },
+      { ANJUTA_TOKEN_SPACE, "ANJUTA_TOKEN_SPACE", "space" },
+      { ANJUTA_TOKEN_START, "ANJUTA_TOKEN_START", "start" },
+      { ANJUTA_TOKEN_NEXT, "ANJUTA_TOKEN_NEXT", "next" },
+      { ANJUTA_TOKEN_LAST, "ANJUTA_TOKEN_LAST", "last" },
+      { ANJUTA_TOKEN_ITEM, "ANJUTA_TOKEN_ITEM", "item" },
+      { ANJUTA_TOKEN_STRING, "ANJUTA_TOKEN_STRING", "string" },
+      { ANJUTA_TOKEN_ERROR, "ANJUTA_TOKEN_ERROR", "error" },
+      { ANJUTA_TOKEN_WORD, "ANJUTA_TOKEN_WORD", "word" },
+      { ANJUTA_TOKEN_LIST, "ANJUTA_TOKEN_LIST", "list" },
+      { ANJUTA_TOKEN_ANY, "ANJUTA_TOKEN_ANY", "any" },
+      { ANJUTA_TOKEN_USER, "ANJUTA_TOKEN_USER", "user" },
+      { ANJUTA_TOKEN_FLAGS, "ANJUTA_TOKEN_FLAGS", "flags" },
+      { ANJUTA_TOKEN_PUBLIC_FLAGS, "ANJUTA_TOKEN_PUBLIC_FLAGS", "public-flags" },
+      { ANJUTA_TOKEN_IRRELEVANT, "ANJUTA_TOKEN_IRRELEVANT", "irrelevant" },
+      { ANJUTA_TOKEN_OPEN, "ANJUTA_TOKEN_OPEN", "open" },
+      { ANJUTA_TOKEN_CLOSE, "ANJUTA_TOKEN_CLOSE", "close" },
+      { ANJUTA_TOKEN_SIGNIFICANT, "ANJUTA_TOKEN_SIGNIFICANT", "significant" },
+      { ANJUTA_TOKEN_PRIVATE_FLAGS, "ANJUTA_TOKEN_PRIVATE_FLAGS", "private-flags" },
+      { ANJUTA_TOKEN_CASE_INSENSITIVE, "ANJUTA_TOKEN_CASE_INSENSITIVE", "case-insensitive" },
+      { ANJUTA_TOKEN_STATIC, "ANJUTA_TOKEN_STATIC", "static" },
+      { ANJUTA_TOKEN_REMOVED, "ANJUTA_TOKEN_REMOVED", "removed" },
+      { ANJUTA_TOKEN_ADDED, "ANJUTA_TOKEN_ADDED", "added" },
+      { 0, NULL, NULL }
+    };
+    etype = g_flags_register_static (g_intern_static_string ("AnjutaTokenType"), values);
   }
   return etype;
 }
