@@ -10,36 +10,38 @@
 [+ == "GPL"  +][+(gpl  (get "Name")                "# ")+]
 [+ESAC+]
 
-import sys
-try:
-    import gtk
-except ImportError:
-    sys.exit("pygtk not found.")
+from gi.repository import Gtk, GdkPixbuf, Gdk
+import os, sys
 
+[+IF (=(get "HaveBuilderUI") "1")+]
 #Comment the first line and uncomment the second before installing
 #or making the tarball (alternatively, use project variables)
-UI_FILE = "data/[+NameHLower+].ui"
+UI_FILE = "[+NameHLower+].ui"
 #UI_FILE = "/usr/local/share/[+NameHLower+]/ui/[+NameHLower+].ui"
-
+[+ENDIF+]
 
 class GUI:
-    def __init__(self):
-        self.builder = gtk.Builder()
-        self.builder.add_from_file(UI_FILE)
-        self.window = self.builder.get_object("window1")
-        self.label = self.builder.get_object("label1")
-        self.builder.connect_signals(self)
-        
-    def change_text(self, widget, *event):
-        self.label.set_text("Hello, pygtk world!")
+	def __init__(self):
+[+IF (=(get "HaveBuilderUI") "1")+]
+		self.builder = Gtk.Builder()
+		self.builder.add_from_file(UI_FILE)
+		self.builder.connect_signals(self)
 
-    def quit(self, widget, *event):
-        gtk.main_quit()
+		window = self.builder.get_object('window')
+[+ELSE+]
+		window = Gtk.Window()
+		window.set_title ("Hello World")
+		window.connect_after('destroy', self.destroy)
+[+ENDIF+]
+
+		window.show_all()
+
+	def destroy(window, self):
+		Gtk.main_quit()
 
 def main():
-    app = GUI()
-    app.window.show()
-    gtk.main()
-
+	app = GUI()
+	Gtk.main()
+		
 if __name__ == "__main__":
     sys.exit(main())
